Learn R Programming

hermite (version 1.0.2)

glm.hermite: Maximum likelihood estimation and Hermite regression

Description

glm.hermite is used to fit generalized linear models with count responses following a Hermite distribution, specified by giving a symbolic description of the linear predictor.

Usage

glm.hermite(formula, data, link="log", start=NULL, m = NULL)

Arguments

formula
symbolic description of the model. A typical predictor has the form response ~ terms where response is the (numeric) response vector and terms is a series of terms which specifies a linear predictor for response.
data
an optional data frame containing the variables in the model.
link
character specification of link function: "log" or "identity". By default link="log".
start
a vector containing the starting values for the parameters of the specified model. Its default value is NULL.
m
value for parameter m. Its default value is NULL, and in that case it will be estimated inside the function.

Value

  • glm.hermite returns a list containing the following components:
    • coefs
    { the vector of coefficients. }
  • dataan optional data frame containing the variables in the model.
  • logliklog-likelihood of the fitted model.
  • vcovcovariance matrix of all coefficients in the model (derived from the Hessian of the maxLik output).
  • hessHessian matrix, returned by the maxLik output.
  • fitted.valuesthe fitted mean values, obtained by transforming the linear predictors by the inverse of the link function.
  • wLikelihood ratio test statistic.
  • pvalLikelihood ratio test p-value.

encoding

utf8

References

Kemp C D, Kemp A W. Some Properties of the Hermite Distribution. Biometrika 1965;52 (3-4):381–394.

McKendrick A G Applications of Mathematics to Medical Problems. Proceedings of the Edinburgh Mathematical Society 1926;44:98–130.

Kemp A W, Kemp C D. An alternative derivation of the Hermite distribution. Biometrika 1966;53 (3-4):627–628.

Patel Y C. Even Point Estimation and Moment Estimation in Hermite Distribution. Biometrics 1976;32 (4):865–873.

Gupta R P, Jain G C. A Generalized Hermite distribution and Its Properties. SIAM Journal on Applied Mathematics 1974;27:359–363.

Bekelis, D. Convolutions of the Poisson laws in number theory. In Analytic & Probabilistic Methods in Number Theory: Proceedings of the 2nd International Conference in Honour of J. Kubilius, Lithuania 1996;4:283–296.

Zhang J, Huang H. On Nonnegative Integer-Valued Lévy Processes and Applications in Probabilistic Number Theory and Inventory Policies. American Journal of Theoretical and Applied Statistics 2013;2:110–121.

Kotz S. Encyclopedia of statistical sciences. John Wiley 1982-1989.

Kotz S. Univariate discrete distributions. Norman L. Johnson 2005.

Puig P. (2003). Characterizing Additively Closed Discrete Models by a Property of Their Maximum Likelihood Estimators, with an Application to Generalized Hermite Distributions. Journal of the American Statistical Association 2003; 98:687–692.

See Also

Distributions for some other distributions, qhermite, phermite, rhermite, hermite-package

Examples

Run this code
data <- c(rep(0,122), rep(1,40), rep(2,14), rep(3,16), rep(4,6), rep(5,2))
mle1 <- glm.hermite(data~1, link="log", start=NULL, m=3)
mle1

Run the code above in your browser using DataLab