mle.hermite(x, a=NA, b=NA, m=NA)NA.NA.NA.a and b. The second element contains the
maximum likelihood value and the third element contains the Hessian matrix. The
fourth element of the returned value contains the likelihood ratio test
statistic $W$ and the last element is the p-value of the likelihood ratio test.a and b. If no initial values are supplied, the naive estimates detailed in Puig (2003) are taken as initial values.McKendrick A G Applications of Mathematics to Medical Problems. Proceedings of the Edinburgh Mathematical Society 1926;44:98–130.
Kemp A W, Kemp C D. An alternative derivation of the Hermite distribution. Biometrika 1966;53 (3-4):627–628.
Patel Y C. Even Point Estimation and Moment Estimation in Hermite Distribution. Biometrics 1976;32 (4):865–873.
Gupta R P, Jain G C. A Generalized Hermite distribution and Its Properties. SIAM Journal on Applied Mathematics 1974;27:359–363.
Bekelis, D. Convolutions of the Poisson laws in number theory. In Analytic & Probabilistic Methods in Number Theory: Proceedings of the 2nd International Conference in Honour of J. Kubilius, Lithuania 1996;4:283–296.
Zhang J, Huang H. On Nonnegative Integer-Valued Lévy Processes and Applications in Probabilistic Number Theory and Inventory Policies. American Journal of Theoretical and Applied Statistics 2013;2:110–121.
Kotz S. Encyclopedia of statistical sciences. John Wiley 1982-1989.
Kotz S. Univariate discrete distributions. Norman L. Johnson 2005.
Puig P. (2003). Characterizing Additively Closed Discrete Models by a Property of Their Maximum Likelihood Estimators, with an Application to Generalized Hermite Distributions. Journal of the American Statistical Association 2003;98:687–692.
Distributions for some other distributions, dhermite, phermite, qhermite, hermite-packagernd <- rhermite(1000, 0.8, 0.3)Run the code above in your browser using DataLab